# robotfwk
Robotframework Keywords library for Web, Mobile, API

## Requirements

Pre-requisites:
* Python 3 is installed
* Pip is installed
* Chrome is installed

## Setup PyCharm

* Clone this repository
* Open directory 'robotfwk' in PyCharm
* Right click on the 'src' directory and select 'set as sources root'
* From Settings, add a virtual environment
* Open the requirements.txt file and right click to install into the virtual environment

## Run the Unit Tests

The unit tests are simple test cases on a simple public website

* In PyCharm open the terminal (check its part of the virtual environment)
* cd into 'scripts\local'
* execute batch file 'run-internet-tests.bat'

## Add InteliBot to PyCharm

This plugin gives syntax highlighting to the .robot files

* From Settings -> Plugins, search for and install InteliBot





